@@ -63,7 +63,7 @@ areainfo <- function(x, theta_lim, which.items = 1:extract.mirt(x, 'nitems'), gr
     nitems <- ifelse(is.null(which.items), extract.mirt(x, 'nitems'), length(which.items))
     ii <- integrate(f, lower = theta_lim[1L], upper = theta_lim[2L],
                     x=x, which.items=which.items, ...)
-    iT <- integrate(f, lower = -10, upper = 10, x=x, which.items=which.items, ...)
+    iT <- integrate(f, lower = -Inf, upper = Inf, x=x, which.items=which.items, ...)
     ret <- data.frame(LowerBound=min(theta_lim), UpperBound=max(theta_lim),
                       Info=ii$value, TotalInfo=iT$value, Proportion=ii$value/iT$value,
                       nitems=nitems)
