@@ -116,7 +116,7 @@ boot.mirt <- function(x, R = 100, boot.fun = NULL, technical = NULL, ...){
     if(missing(x)) missingMsg('x')
     if(x@Options$exploratory)
         warning('Note: bootstrapped standard errors for slope parameters in exploratory
-                       models are not meaningful.')
+                       models are not meaningful.', call.=FALSE)
     dat <- x@Data$data
     itemtype <- x@Model$itemtype
     class <- class(x)
